import 'package:flutter/cupertino.dart';

class BouncingButtonAnimation extends StatefulWidget {
  final Widget child;
  final double upperBound;
  final Function()? onPressed;

  const BouncingButtonAnimation({
    required this.child,
    this.upperBound = 0.1,
    this.onPressed,
  });

  @override
  State<StatefulWidget> createState() => BouncingButtonAnimationState();
}

class BouncingButtonAnimationState extends State<BouncingButtonAnimation>
    with TickerProviderStateMixin {
  late AnimationController animationController;

  @override
  void initState() {
    const duration = Duration(milliseconds: 100);
    animationController = AnimationController(
      vsync: this,
      duration: duration,
      reverseDuration: duration,
      upperBound: widget.upperBound,
    );
    animationController.addListener(() => setState(() {}));
    super.initState();
  }

  @override
  void dispose() {
    animationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    if (widget.onPressed == null) {
      return widget.child;
    }
    return GestureDetector(
      onTapDown: (_) {
        animationController.forward();
      },
      onTapCancel: () {
        animationController.reverse();
      },
      onTapUp: (_) {
        animationController.reverse();
      },
      onTap: () {
        animationController.forward().then((value) => animationController.reverse());
        widget.onPressed!();
      },
      child: Transform.scale(
          scale: 1 - animationController.value,
          child: widget.child,
      ),
    );
  }

}
