import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:training_lights/common/responsive/fitted_text.dart';
import 'package:training_lights/global/notify_listeners/tangle_manager/tangle_manager.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/utils/languages/language.dart';

class ConnectionStateButton extends StatefulWidget {
  final Color? backgroundColor;

  const ConnectionStateButton({
    this.backgroundColor,
  });

  @override
  State<StatefulWidget> createState() => _ConnectionStateButton();
}

class _ConnectionStateButton extends State<ConnectionStateButton> {
  late bool connectedForText;
  bool? connectedForPoint;
  final Duration animationDuration = const Duration(milliseconds: 300);

  void _setConnectedProps(bool connected) {
    connectedForText = connected;
    if (connectedForPoint != null && connectedForPoint != connected) {
      Future.delayed(animationDuration, () {
        setState(() {
          connectedForPoint = connected;
        });
      });
    } else {
      connectedForPoint = connected;
    }
  }

  @override
  Widget build(BuildContext context) {
    final theme = myTheme();
    final language = Language.of(context);

    return Consumer<TangleManager>(
        builder: (_, tangle, __) {
          _setConnectedProps(tangle.isReady);

          return ElevatedButton(
            style: ElevatedButton.styleFrom(
              minimumSize: const Size(0, 40),
              primary: widget.backgroundColor ?? theme.backgroundColor,
              shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(24),
              ),
            ),
            onPressed: () => Navigator.of(context).pushNamed('/pairing'),
            child: Row(
              mainAxisSize: MainAxisSize.min,
              children: [
                AnimatedSwitcher(
                  duration: animationDuration,
                  transitionBuilder: (child, scale) {
                    return ScaleTransition(
                      scale: scale,
                      child: child,
                    );
                  },
                  child: Container(
                    key: ValueKey(connectedForPoint!),
                    height: 8,
                    width: 8,
                    margin: EdgeInsets.symmetric(
                      horizontal: MediaQuery.of(context).size.width > 350 ? 12 : 5,
                    ),
                    decoration: BoxDecoration(
                      color: connectedForPoint! ? Colors.green : Colors.red,
                      shape: BoxShape.circle,
                    ),
                  ),
                ),
                Flexible(
                  child: Container(
                      margin: const EdgeInsets.only(right: 8),
                      child: AnimatedSwitcher(
                        duration: animationDuration,
                        transitionBuilder: (child, animation) {
                          if (child.key == const ValueKey(true)) {
                            return _textAnimation(
                              animation,
                              child,
                              fromBottom: true,
                            );
                          } else {
                            return _textAnimation(
                                animation,
                                child,
                                fromBottom: false,
                            );
                          }
                        },
                        child: FittedText(
                          connectedForText ?
                            language.connectionStateButtonLightsConnected
                                :
                            language.connectionStateButtonLightsDisconnected,
                          key: ValueKey(connectedForText),
                          style: theme.textTheme.subtitle1,
                        ),
                      ),
                  ),
                )
              ],
            ),
          );
        },
    );
  }

  Widget _textAnimation(Animation<double> animation, Widget child,
      {required bool fromBottom,}) {
    return SlideTransition(
      position: Tween<Offset>(
          begin: Offset(0.0, fromBottom ? -0.9 : 0.9),
          end: Offset.zero,
      ).animate(animation),
      child: FadeTransition(
        opacity: animation,
        child: child,
      ),
    );
  }
}
