import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:training_lights/common/buttons/primary_button.dart';
import 'package:training_lights/common/dialogs/upload_training_dialog.dart';
import 'package:training_lights/common/wrappers/my_snack_bar.dart';
import 'package:training_lights/global/notify_listeners/tangle_manager/tangle_manager.dart';
import 'package:training_lights/models/training_model/training.dart';
import 'package:training_lights/utils/languages/language.dart';
import 'package:training_lights/utils/show_dialog.dart';

class PlayTrainingButton extends StatelessWidget {
  final TrainingModel training;

  const PlayTrainingButton({required this.training});

  @override
  Widget build(BuildContext context) {
    return Consumer<TangleManager>(
        builder: (context, tangle, __) {
          final language = Language.of(context);
          return PrimaryButton(
            onPressed: () {
              if (tangle.isReady) {
                ShowDialog.show(
                    context: context,
                    child: UploadTrainingDialog(
                      trainingModel: training,
                    ),
                );
              } else {
                ScaffoldMessenger.of(context).showSnackBar(
                  MySnackBar(
                    text: language.snackBarTrainingCannotBeStartedLightsDisconnected,
                  ),
                );
              }
            },
            text: language.start,
          );
        },
    );
  }

}
