import 'package:flutter/material.dart';
import 'package:training_lights/common/animations/bouncing_button_animation.dart';
import 'package:training_lights/global/enums/primary_button_design.dart';
import 'package:training_lights/my_theme.dart';

class PrimaryButton extends StatelessWidget {
  final String text;
  final Widget? iconLeft;
  final Widget? iconRight;
  final Function()? onPressed;
  final PrimaryButtonDesign? buttonDesign;

  const PrimaryButton({
    required this.text,
    required this.onPressed,
    this.iconLeft,
    this.iconRight,
    this.buttonDesign,
  });

  @override
  Widget build(BuildContext context) {
    final theme = myTheme();
    final currentSize = MediaQuery.of(context).size;
    final Widget fittedText = Text(
      text,
      style: theme.textTheme.subtitle1!.copyWith(color: _textColor(context, theme)),
    );
    final borderRadius = BorderRadius.circular(12);

    Widget child;
    if (iconLeft == null && iconRight == null) {
      child = fittedText;
    } else {
      child = Row(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          iconLeft ?? Container(height: 0,),
          if (iconLeft != null)
            const SizedBox(
              width: 10,
            ),
          Flexible(
              child: fittedText,
          ),
          if (iconRight != null)
            const SizedBox(
              width: 10,
            ),
          iconRight ?? Container(height: 0,),
        ],
      );
    }

    return Opacity(
      opacity: onPressed == null ? 0.6 : 1,
      child: BouncingButtonAnimation(
        onPressed: onPressed,
        child: Container(
          height: currentSize.height * 0.065,
          width: currentSize.width,
          constraints: const BoxConstraints(
              minHeight: 40,
              maxHeight: 55,
          ),
          decoration: BoxDecoration(
            color: _backgroundColor(context, theme),
            borderRadius: borderRadius,
            gradient: buttonDesign == null ? LinearGradient(
                begin: Alignment.topCenter,
                end: Alignment.bottomCenter,
                colors: [
                  theme.buttonTheme.colorScheme!.primary,
                  theme.buttonTheme.colorScheme!.secondary,
                ],
            ) : null,
            boxShadow: buttonDesign == null ? [
            BoxShadow(
              color: theme.buttonTheme.colorScheme!.onSurface,
              spreadRadius: 10,
              blurRadius: 30,
              offset: const Offset(0, 10),
            ),
            ] : null,
          ),
          child: Center(
            child: child,
          ),
        ),
      ),
    );
  }

  Color? _backgroundColor(BuildContext context, ThemeData theme) {
    switch(buttonDesign) {
      case null:
        return null; // linear gradient is displayed instead of only one color
      case PrimaryButtonDesign.accentColorOnDark:
        return theme.colorScheme.secondary.withOpacity(0.2);
      case PrimaryButtonDesign.darkColorOnDark:
        return theme.cardColor;
      case PrimaryButtonDesign.darkColorOnAccent:
        return theme.primaryColor;
      case PrimaryButtonDesign.darkRedColor:
        return theme.errorColor.withOpacity(0.2);
      case PrimaryButtonDesign.lightRedColor:
        return theme.errorColor.withAlpha(205);
    }
  }

  Color? _textColor(BuildContext context, ThemeData theme) {
    switch(buttonDesign) {
      case null:
        return null;
      case PrimaryButtonDesign.accentColorOnDark:
        return theme.colorScheme.secondary;
      case PrimaryButtonDesign.darkColorOnDark:
        return null; //white
      case PrimaryButtonDesign.darkColorOnAccent:
        return null; //white
      case PrimaryButtonDesign.darkRedColor:
        return theme.errorColor;
      case PrimaryButtonDesign.lightRedColor:
        return null;
    }
  }

}
