import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:training_lights/common/fallback_image.dart';
import 'package:training_lights/common/wrappers/my_card.dart';
import 'package:training_lights/global/services.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/utils/languages/language.dart';

class ThumbnailCard extends StatelessWidget {
  final String thumbnailKey;
  final String title;
  final String subtitle;
  final Function() onTap;
  final Widget actionButtons;
  final String? description;
  final String? category;

  const ThumbnailCard({
    required this.thumbnailKey,
    required this.title,
    required this.subtitle,
    required this.onTap,
    required this.actionButtons,
    this.description,
    this.category,
  });

  @override
  Widget build(BuildContext context) {
    final theme = myTheme();
    final language = Language.of(context);

    return MyCard(
      child: GestureDetector(
        onTap: onTap,
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Padding(
              padding: const EdgeInsets.all(8.0),
              child: Row(
                children: [
                  Container(
                    height: MediaQuery.of(context).size.height * 0.09,
                    constraints: const BoxConstraints(
                      maxHeight: 90,
                      minHeight: 60,
                    ),
                    child: Consumer<Services>(
                      builder: (_, services, __) {
                        return ClipRRect(
                          borderRadius: BorderRadius.circular(12),
                          child: CachedNetworkImage(
                            imageUrl: services.video.getThumbnailPath(thumbnailKey),
                            errorWidget: (_, __, ___) => FallbackImage(
                              errorText: language.cantLoadImage,
                            ),
                          ),
                        );
                      },
                    ),
                  ),
                  const SizedBox(width: 15,),
                  Flexible(
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        if (category != null)
                          Text(
                              category!,
                              style: theme.textTheme.bodyText2,
                          ),
                        Text(
                            title,
                            style: theme.textTheme.headline2,
                        ),
                        Text(
                          subtitle,
                          style: theme.textTheme.subtitle2,
                        ),
                      ],
                    ),
                  )
                ],
              ),
            ),
            if (description != null)
              Container(
                padding: const EdgeInsets.all(8.0),
                alignment: Alignment.centerLeft,
                child: Text(
                  description!,
                  style: myTheme().textTheme.bodyText2,
                ),
              ),
            Padding(
                padding: const EdgeInsets.all(8.0),
                child: actionButtons,
            ),
          ],
        ),
      ),
    );
  }
}
