import 'dart:async';

import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:training_lights/common/buttons/primary_button.dart';
import 'package:training_lights/common/dialogs/widgets/icon_dialog_content.dart';
import 'package:training_lights/common/my_icons/my_icons.dart';
import 'package:training_lights/common/wrappers/my_dialog.dart';
import 'package:training_lights/global/enums/primary_button_design.dart';
import 'package:training_lights/global/notify_listeners/tangle_manager/tangle_manager.dart';
import 'package:training_lights/models/training_model/training.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/utils/languages/language.dart';

enum UploadState {
  uploading, uploadSuccessful, error
}

class UploadTrainingDialog extends StatefulWidget {
  final TrainingModel trainingModel;

  const UploadTrainingDialog({
    required this.trainingModel,
  });

  @override
  State<StatefulWidget> createState() => UploadTrainingDialogState();
}

class UploadTrainingDialogState extends State<UploadTrainingDialog> {
  late UploadState _uploadState;

  @override
  void initState() {
    _uploadState = UploadState.uploading;
    _uploadTraining();
    super.initState();
  }

  void _uploadTraining() {
    setState(() => _uploadState = UploadState.uploading);
    context.read<TangleManager>().uploadTraining(widget.trainingModel)
        .then((value) => setState(() => _uploadState = UploadState.uploadSuccessful))
        .onError((error, stackTrace) => setState(() => _uploadState = UploadState.error));
  }

  @override
  Widget build(BuildContext context) {
    final language = Language.of(context);

    String contentText;
    IconData icon;
    Color color;
    switch (_uploadState) {
      case UploadState.uploading:
        contentText = language.uploadTrainingDialogUploading;
        icon = Icons.upload;
        color = myTheme().colorScheme.secondary;
        break;
      case UploadState.uploadSuccessful:
        contentText = language.uploadTrainingDialogUploadSuccessful;
        icon = MyIcons.confirm;
        color = myTheme().colorScheme.secondary;
        Timer(const Duration(seconds: 1), () {
          final navigator = Navigator.of(context);
          navigator.pop();
          navigator.pushNamed(
              '/countdown',
              arguments: widget.trainingModel,
          );
        });
        break;
      case UploadState.error:
        contentText = language.uploadTrainingDialogError;
        icon = Icons.error_outline;
        color = myTheme().errorColor;
        break;
    }

    return MyDialog(
      title: language.uploadTrainingDialogTitle,
      content: IconDialogContent(
        icon: icon,
        iconColor: color,
        contentText: contentText,
        displayIndicator: _uploadState == UploadState.uploading,
      ),
      action: _uploadState == UploadState.error ? PrimaryButton(
        buttonDesign: PrimaryButtonDesign.lightRedColor,
        onPressed: () => _uploadTraining(),
        text: language.uploadTrainingDialogTryAgain,
      ) : null,
    );
  }
}
