import 'package:chewie/chewie.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:training_lights/common/fallback_image.dart';
import 'package:training_lights/common/video/video_aspect_ratio.dart';
import 'package:training_lights/common/wrappers/my_futurebuilder.dart';
import 'package:training_lights/global/services.dart';
import 'package:training_lights/utils/languages/language.dart';
import 'package:video_player/video_player.dart';
import 'package:visibility_detector/visibility_detector.dart';

class VideoPlayerScreen extends StatefulWidget {
  final String videoKey;
  final bool inAppBar;

  const VideoPlayerScreen({
    required this.videoKey,
    this.inAppBar = false,
  });

  @override
  State<StatefulWidget> createState() => VideoPlayerScreenState();
}

class VideoPlayerScreenState extends State<VideoPlayerScreen> {
  ChewieController? chewieController;
  VideoPlayerController? videoPlayerController;

  @override
  void dispose() {
    chewieController?.dispose();
    videoPlayerController?.dispose();
    videoPlayerController = null; // don't execute controller.pause after visibility 0
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return VisibilityDetector(
        key: const Key('VideoPlayerScreen'),
        onVisibilityChanged: (VisibilityInfo info) {
          if(info.visibleFraction == 0){
            videoPlayerController?.pause();
          }
          else{
            videoPlayerController?.play();
          }
        },
        child: Consumer<Services>(
            builder: (_, services, __) => MyFutureBuilder<VideoPlayerController>(
              future: services.video.getControllerForVideo(widget.videoKey),
              onError: FallbackImage(
                  errorText: Language.of(context).recommendedTrainingRouteCantLoadVideo,
              ),
              builder: (_videoPlayerController) {
                videoPlayerController = _videoPlayerController;
                chewieController = ChewieController(
                    videoPlayerController: videoPlayerController!,
                    aspectRatio: VideoAspectRatio.getAspectRatioForVideo(),
                    autoPlay: true,
                    looping: widget.inAppBar,
                    allowFullScreen: !widget.inAppBar,
                    showControls: !widget.inAppBar,
                );
                return Chewie(controller: chewieController!);
              },
            ),
        ),
    );
  }
}
