import 'package:flex_color_picker/flex_color_picker.dart';
import 'package:flutter/material.dart';
import 'package:training_lights/global/enums/tangle_color.dart';

class MyColorPicker extends StatelessWidget {
  final TangleColor color;
  final Function(TangleColor) setColor;
  final Function()? wasSomethingEdited;

  const MyColorPicker({
    required this.color,
    required this.setColor,
    this.wasSomethingEdited,
  });

  @override
  Widget build(BuildContext context) {
    return ColorPicker(
      pickersEnabled: const {
        ColorPickerType.accent: false,
        ColorPickerType.primary: false,
        ColorPickerType.custom: true,
      },
      customColorSwatchesAndNames: colors,
      enableShadesSelection: false,
      color: color.materialColor,
      borderRadius: 30,
      spacing: 7,
      runSpacing: 7,
      onColorChanged: (Color newColor) {
        setColor(TangleColor.fromMaterial(newColor));
        wasSomethingEdited?.call();
      },
    );
  }


  static Map<ColorSwatch<Object>, String> get colors => {
    for (TangleColor color in [
      TangleColor.red,
      TangleColor.orange,
      TangleColor.yellow,
      TangleColor.green,
      TangleColor.lightBlue,
      TangleColor.blue,
      TangleColor.purple,
      TangleColor.white,
    ])
    asSwatch(color) : color.key
  };

  static ColorSwatch<Object> asSwatch(TangleColor color) {
    return ColorTools.createPrimarySwatch(color.materialColor);
  }
}
