import 'dart:ui';
import 'package:flutter/material.dart';
import 'package:training_lights/common/buttons/action_circle_button.dart';
import 'package:training_lights/common/my_icons/my_icons.dart';
import 'package:training_lights/my_theme.dart';

class MyDialog extends StatelessWidget {
  final String? title;
  final Widget? action;
  final Widget? content;
  final bool videoDialog;

  const MyDialog({
    this.title,
    this.action,
    this.content,
    this.videoDialog = false,
  });

  @override
  Widget build(BuildContext context) {
    const double blur = 10;
    const padding = EdgeInsets.all(16);

    return BackdropFilter(
      filter: ImageFilter.blur(sigmaX: blur, sigmaY: blur),
      child: AlertDialog(
        insetPadding: const EdgeInsets.symmetric(horizontal: 20),
        contentPadding: videoDialog ? EdgeInsets.zero : padding,
        titlePadding: padding,
        actionsPadding: padding,
        buttonPadding: EdgeInsets.zero,
        backgroundColor: videoDialog ? Colors.transparent : null,
        contentTextStyle: myTheme().textTheme.bodyText2,
        shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(12),
        ),
        title: title != null ? Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            Flexible(
              child: Text(
                title!,
                style: myTheme().textTheme.subtitle1,
              ),
            ),
            ActionCircleButton(
                darkMode: true,
                icon: MyIcons.crossSmall,
                onPressed: () {
                  Navigator.pop(context);
                },
            )
          ],
        ) : null,
        content: content,
        actions: action != null ? [
          action!
        ] : null,
      ),
    );
  }
}
