import 'package:flutter/material.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/utils/languages/language.dart';
import 'package:training_lights/utils/logger.dart';

class MyFutureBuilder<T> extends StatelessWidget {
  final log = getLogger('MyFutureBuilder');

  final Future<T> future;
  final Widget Function(T) builder;
  final Widget? onError;
  final Widget? onLoading;
  final bool withConnectionState;

  MyFutureBuilder({
    required this.future,
    required this.builder,
    this.onError,
    this.onLoading,
    this.withConnectionState = false,
  });

  @override
  Widget build(BuildContext context) {
    return FutureBuilder(
      future: future,
      builder: (context, snapshot) {
        if (snapshot.hasError) {
          log.e(snapshot.error);
          return onError ?? Text(
            Language.of(context).myFutureBuilderLoadingError,
            style: myTheme().textTheme.subtitle1,
          );
        }

        if (withConnectionState) {
          if (snapshot.connectionState == ConnectionState.done) {
            return builder(snapshot.data as T);
          }
        } else {
          if (snapshot.hasData) {
            return builder(snapshot.data as T);
          }
        }

        return onLoading ?? const Center(child: CircularProgressIndicator());
      },
    );
  }
}
