import 'package:flutter/material.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/utils/languages/language.dart';
import 'package:training_lights/utils/logger.dart';

class MyStreamBuilder<T> extends StatelessWidget {
  final log = getLogger('MyFutureBuilder');

  final Stream stream;
  final T initialData;
  final Widget Function(T) builder;
  final Widget? onError;
  final Widget? onLoading;

  MyStreamBuilder({
    required this.stream,
    required this.initialData,
    required this.builder,
    this.onError,
    this.onLoading,
  });

  @override
  Widget build(BuildContext context) {
    final language = Language.of(context);

    return StreamBuilder(
      stream: stream,
      initialData: initialData,
      builder: (context, snapshot) {
        if (snapshot.hasError) {
          log.e(snapshot.error);
          return Center(child: onError ?? Text(
            language.myStreamBuilderLoadingError,
            style: myTheme().textTheme.subtitle1,
          ),);
        }
        if (snapshot.hasData) {
          return builder(snapshot.data as T);
        }
        return onLoading ??  Center(child: Column(
          children: [
            Text(language.myStreamBuilderLoading),
            const SizedBox(height: 20.0,),
            const CircularProgressIndicator()
          ],
        ),);
      },
    );
  }
}
