import 'package:flutter/material.dart';

const myBlue = Color.fromRGBO(22, 111, 206,1);

ThemeData myTheme() {
  const brightness = Brightness.dark;
  const primaryColor = Colors.black;
  const accentColor = Color.fromRGBO(140, 182, 39, 1);
  const errorColor = Color.fromRGBO(255, 47, 83, 1);
  const dialogBackgroundColor = Color.fromRGBO(26, 26, 26, 1);
  const fontFamily = 'Poppins';
  final whiteText = Colors.white.withOpacity(0.9);

  return ThemeData(
    fontFamily: fontFamily,
    brightness: brightness,
    primaryColor: primaryColor, // Tabs, ProgressIndicator, etc..
    //dialogBackgroundColor: accentColor,
    canvasColor: primaryColor,
    errorColor: errorColor,

    dividerColor: Colors.transparent,
    hintColor: primaryColor, // Hint text, placeholder text eg. Textfields
    cardColor: Colors.white10,
    primaryColorLight: Colors.white,
    backgroundColor: Colors.white.withOpacity(0.2),
    disabledColor: Colors.white54,
    highlightColor: Colors.white,
    dialogBackgroundColor: dialogBackgroundColor,

    colorScheme: ColorScheme.fromSwatch(brightness: brightness).copyWith(
      secondary: accentColor,
      tertiaryContainer: Colors.white24,
    ),

    checkboxTheme: CheckboxThemeData(
      shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(6),),
      side: const BorderSide(
        width: 2,
        color: Colors.white24,
      ),
      fillColor: MaterialStateProperty.all(Colors.white),
      checkColor: MaterialStateProperty.all(Colors.black87),
    ),

    buttonTheme: const ButtonThemeData(
      colorScheme: ColorScheme.dark(
        // for linear gradient in primary elevated button
        primary: Color.fromRGBO(159, 203, 51, 1),
        secondary: Color.fromRGBO(127, 167, 30, 1),
        // for shadow of primary elevated button
        onSurface: Color.fromRGBO(150, 225, 32, 0.1),
      ),
    ),

    elevatedButtonTheme: ElevatedButtonThemeData(
        style: ElevatedButton.styleFrom(
          shadowColor: Colors.transparent,
        ),
    ),

    textButtonTheme: TextButtonThemeData(
        style: TextButton.styleFrom(
            primary: accentColor,
        ),
    ),

    snackBarTheme: const SnackBarThemeData(
        backgroundColor: primaryColor,
        behavior: SnackBarBehavior.fixed,
    ),

    primaryTextTheme: const TextTheme(
      headline1: TextStyle(fontSize: 30, color: primaryColor, fontWeight: FontWeight.w600),
    ),

    textTheme: TextTheme(
      headline1: TextStyle(fontSize: 24, color: whiteText, fontWeight: FontWeight.w600), // Route title
      headline2: TextStyle(fontSize: 18, color: whiteText, fontWeight: FontWeight.w600), // Card/article title

      subtitle1: TextStyle(fontSize: 16, color: whiteText, fontWeight: FontWeight.w600),
      subtitle2: const TextStyle(fontSize: 16, color: Colors.white60, fontWeight: FontWeight.w400), // Card/article subtitle

      bodyText2: const TextStyle(fontSize: 14, color: Colors.white60, fontWeight: FontWeight.w400), // Default body style
      // NOT USED
      headline3: const TextStyle(fontSize: 20, color: Colors.purple, fontStyle: FontStyle.normal),
      headline4: const TextStyle(fontSize: 20, color: Colors.purple, fontStyle: FontStyle.normal),
      headline5: const TextStyle(fontSize: 20, color: Colors.purple, fontStyle: FontStyle.normal),
      headline6: const TextStyle(fontSize: 20, color: Colors.purple, fontStyle: FontStyle.normal),
      bodyText1: const TextStyle(fontSize: 20, color: Colors.purple, fontStyle: FontStyle.normal),
      //caption
      overline: const TextStyle(fontSize: 11, color: accentColor, fontWeight: FontWeight.w500),
    ),
    // Adapts visual density to specific platform
    visualDensity: VisualDensity.adaptivePlatformDensity,
  );
}
