import 'package:flutter/material.dart';
import 'package:training_lights/models/training_model/recommended_training_model/recommended_training.dart';
import 'package:training_lights/models/training_model/training.dart';
import 'package:training_lights/routes/about_us_route/about_us_route.dart';
import 'package:training_lights/routes/contact_route/contact_route.dart';
import 'package:training_lights/routes/countdown_route/countdown_route.dart';
import 'package:training_lights/routes/create_training_route/create_training_route.dart';
import 'package:training_lights/routes/home_route.dart';
import 'package:training_lights/routes/menu_route/menu_route.dart';
import 'package:training_lights/routes/number_lights_route/number_lights_route.dart';
import 'package:training_lights/routes/pairing_route/pairing_route.dart';
import 'package:training_lights/routes/recommended_training_route/recommended_training_route.dart';
import 'package:training_lights/routes/setting_route/setting_route.dart';
import 'package:training_lights/routes/tangle_control_route/tangle_control_route.dart';
import 'package:training_lights/routes/training_list_route/training_list_route.dart';
import 'package:training_lights/utils/logger.dart';

class RouteGenerator {
  static final log = getLogger('RouteGenerator');

  static Route<dynamic> generate (RouteSettings settings) {
    final name = settings.name;

    log.i('Opening new route "$name"');
    return MaterialPageRoute(builder: (context) => _getRouteWidget(name,settings));
  }

  static Widget _getRouteWidget(String? name, RouteSettings settings) {
    final args = settings.arguments ?? Object();
    switch (name) {
      case '/':
        return HomeRoute();
      case '/menu':
        return MenuRoute();
      case '/setting':
        return SettingRoute();
      case '/aboutUs':
        final aboutUsRouteArgs = args as AboutUsRouteArgs;
        return AboutUsRoute(args: aboutUsRouteArgs); // if argument is true, scroll to instruction videos
      case '/contact':
        return ContactRoute();
      case '/control':
        return TangleControlRoute();
      case '/pairing':
        return PairingRoute();
      case '/trainings':
        return TrainingsListRoute();
      case '/numberLights':
        return NumberLightsRoute();
      case '/createTraining':
        final createTrainingRouteArgs = args as CreateTrainingRouteArgs;
        return CreateTrainingRoute(args: createTrainingRouteArgs,);
      case '/recommendedTraining':
        final recommendedTraining = args as RecommendedTraining;
        return RecommendedTrainingRoute(recommendedTraining: recommendedTraining);
      case '/countdown':
        final trainingModel = args as TrainingModel;
        return CountdownRoute(trainingModel: trainingModel);
      default:
        final String message = 'Undefined route $name';
        log.wtf(message);
        throw message;
    }
  }
}
