import 'package:flutter/material.dart';
import 'package:training_lights/common/buttons/menu_button.dart';
import 'package:training_lights/common/buttons/primary_button.dart';
import 'package:training_lights/common/buttons/web_button.dart';
import 'package:training_lights/common/cards/thumbnail_card.dart';
import 'package:training_lights/common/scaffold_titles/left_align_text_title.dart';
import 'package:training_lights/common/wrappers/my_scaffold.dart';
import 'package:training_lights/global/enums/primary_button_design.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/routes/about_us_route/widgets/video_dialog.dart';
import 'package:training_lights/utils/languages/language.dart';
import 'package:training_lights/utils/show_dialog.dart';

class AboutUsRouteArgs {
  final bool scrollDown;

  AboutUsRouteArgs({required this.scrollDown});
}

class AboutUsRoute extends StatelessWidget {
  final AboutUsRouteArgs args;

  const AboutUsRoute({
    required this.args,
  });

  @override
  Widget build(BuildContext context) {
    final language = Language.of(context);
    const spacer = SizedBox(height: 30,);

    return MyScaffold(
        title: LeftAlignTextTitle(
          text: language.aboutUs,
        ),
        alignTitleLeft: true,
        actionButton: MenuButton(),
        isBackButtonDisplayed: false,
        isBottomGradientDisplayed: false,
        body: ListView(
          children: [
            _textAboutUs(context, language),
            spacer,
            WebButton(),
            spacer,
            _instructionVideos(context, language)
          ],
        ),
    );
  }

  Widget _textAboutUs(BuildContext context, Language language) {
    return Text(
      language.aboutUsRouteArticle,
      style: myTheme().textTheme.bodyText2,
    );
  }

  Widget _instructionVideos(BuildContext context, Language language) {
    final textTheme = myTheme().textTheme;
    const spacer = SizedBox(height: 5,);

    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Builder(
          builder: (context) {
            if (args.scrollDown) {
              WidgetsBinding.instance!
                  .addPostFrameCallback((_) => Scrollable.ensureVisible(context),
              );
            }

            return Text(
              language.aboutUsRouteInstructionTitle,
              style: textTheme.headline2,
            );
          },
        ),
        spacer,
        _thumbnailCard( // TODO
          context: context,
          language: language,
          key: 'block',
          title: 'Title',
          subtitle: 'Subtitle',
          category: 'Basic',
        ),
        spacer,
        _thumbnailCard( // TODO
          context: context,
          language: language,
          key: 'spike',
          title: 'Title2',
          subtitle: 'Subtitle2',
          category: 'Basic2',
        ),
        spacer
      ],
    );
  }

  Widget _thumbnailCard({
    required BuildContext context,
    required Language language,
    required String key,
    required String title,
    required String subtitle,
    required String category,
  }) {
    void showDialog() => ShowDialog.show(
        darkerBackground: true,
        context: context,
        child: VideoDialog(videoKey: key,),
    );

    return ThumbnailCard(
        thumbnailKey: key,
        title: title,
        subtitle: subtitle,
        category: category,
        onTap: showDialog,
        actionButtons: PrimaryButton(
          buttonDesign: PrimaryButtonDesign.accentColorOnDark,
          onPressed: showDialog,
          text: language.display,
        ),
    );
  }
}
