import 'package:flutter/material.dart';
import 'package:training_lights/common/buttons/menu_button.dart';
import 'package:training_lights/common/buttons/primary_button.dart';
import 'package:training_lights/common/buttons/web_button.dart';
import 'package:training_lights/common/scaffold_titles/left_align_text_title.dart';
import 'package:training_lights/common/wrappers/my_scaffold.dart';
import 'package:training_lights/global/enums/primary_button_design.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/routes/contact_route/widgets/company_info.dart';
import 'package:training_lights/utils/languages/language.dart';
import 'package:url_launcher/url_launcher.dart';

class ContactRoute extends StatelessWidget {
  static const String toMailId = 'support@training-lights.com';

  @override
  Widget build(BuildContext context) {
    final language = Language.of(context);
    const SizedBox spacer16 = SizedBox(
      height: 16,
    );
    const SizedBox spacer32 = SizedBox(
      height: 32,
    );

    return MyScaffold(
        title: LeftAlignTextTitle(
          text: language.contact,
        ),
        alignTitleLeft: true,
        actionButton: MenuButton(),
        isBackButtonDisplayed: false,
        isBottomGradientDisplayed: false,
        body: ListView(
          children: [
            CompanyInfo(),
            spacer32,
            PrimaryButton(
              text: language.contactRouteCallUs,
              onPressed: () => launch('tel://+420777376909'),
              buttonDesign: PrimaryButtonDesign.darkColorOnDark,
            ),
            spacer16,
            PrimaryButton(
              text: language.contactRouteWriteUs,
              onPressed: () => launch('mailto:$toMailId'),
              buttonDesign: PrimaryButtonDesign.darkColorOnDark,
            ),
            spacer32,
            for (final pair in {
              language.contactRouteAppUsageTitle: language.contactRouteAppUsageBody,
              language.contactRouteControllerUsageTitle: language.contactRouteControllerUsageBody,
              language.contactRouteDeletionTrainingTitle: language.contactRouteDeletionTrainingBody
            }.entries)
              Column(
                children: [
                  ExpansionTile(
                    collapsedIconColor: myTheme().primaryColorLight,
                    tilePadding: EdgeInsets.zero,
                    title: Text(
                      pair.key,
                      style: myTheme().textTheme.headline2,
                    ), // title
                    children: [
                      Align(
                        alignment: Alignment.centerLeft,
                        child: Text(
                          pair.value,
                          style: myTheme().textTheme.bodyText2,
                        ),
                      )
                    ], // body
                  ),
                  spacer16,
                ],
              ),
            WebButton(),
            spacer16,
          ],
        ),);
  }
}
