import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:training_lights/common/buttons/connection_state_button.dart';
import 'package:training_lights/common/dialogs/upload_training_dialog.dart';
import 'package:training_lights/global/notify_listeners/tangle_manager/tangle_manager.dart';
import 'package:training_lights/models/training_model/training.dart';
import 'package:training_lights/routes/create_training_route/widgets/buttons/bottom_action_button.dart';
import 'package:training_lights/utils/show_dialog.dart';

class ActionBottomAppBar extends StatelessWidget {
  final TrainingModel Function(BuildContext context, {bool showSnackBar}) saveTraining;
  final bool areChangesSaved;

  const ActionBottomAppBar({
    required this.saveTraining,
    required this.areChangesSaved,
  });

  @override
  Widget build(BuildContext context) {
    return Container(
      height: MediaQuery.of(context).size.height * 0.125,
      constraints: const BoxConstraints(
        minHeight: 40,
        maxHeight: 100,
      ),
      child: BottomAppBar(
        color: Colors.transparent,
        child: Row(
          mainAxisAlignment: MainAxisAlignment.spaceAround,
          children: [
            Consumer<TangleManager>(
              builder: (_, tangle, __) {
                return BottomActionButton(
                  onPressed: tangle.isReady ? () {
                    final TrainingModel trainingModel = saveTraining(context, showSnackBar: false);
                    ShowDialog.show(
                      context: context,
                      child: UploadTrainingDialog(
                        trainingModel: trainingModel,
                      ),
                    );
                  } : null,
                  isSaveButton: false,
                );
              },
            ),
            const Flexible(
              child: ConnectionStateButton(),
            ),
            BottomActionButton(
              onPressed: !areChangesSaved ? () => saveTraining(context) : null,
              isSaveButton: true,
            ),
          ],
        ),
      ),
    );
  }
}
