import 'package:flutter/material.dart';
import 'package:training_lights/common/buttons/primary_button.dart';
import 'package:training_lights/global/enums/primary_button_design.dart';
import 'package:training_lights/global/enums/tangle_color.dart';
import 'package:training_lights/models/training_model/colorizable.dart';
import 'package:training_lights/routes/create_training_route/widgets/dialogs/color_selection_dialog.dart';
import 'package:training_lights/utils/languages/language.dart';
import 'package:training_lights/utils/show_dialog.dart';

class ColorSelectionButton extends StatefulWidget {
  final Colorizable blick;
  final Function() wasSomethingEdited;

  const ColorSelectionButton({
    required this.blick,
    required this.wasSomethingEdited,
  });

  @override
  State<StatefulWidget> createState() => _ColorSelectionButton();
}

class _ColorSelectionButton extends State<ColorSelectionButton> {
  late TangleColor _color;

  @override
  void initState() {
    _color = widget.blick.color;
    super.initState();
  }

  void setColor(TangleColor newColor) {
    setState(() {
      _color = newColor;
      widget.blick.color = newColor;
    });
  }

  @override
  Widget build(BuildContext context) {
    return PrimaryButton(
        buttonDesign: PrimaryButtonDesign.darkColorOnDark,
        onPressed: () {
          ShowDialog.show(
            context: context,
            child: ColorSelectionDialog(
                color: _color,
                setColor: setColor,
                wasSomethingEdited: widget.wasSomethingEdited,
            ),
          );
        },
        text: Language.of(context).createTrainingRouteColorSelectionButtonText,
        iconRight: Container(
          height: 15,
          width: 15,
          decoration: BoxDecoration(
            color: _color.materialColor,
            shape: BoxShape.circle,
          ),
        ),
    );
  }

}
