import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/routes/create_training_route/widgets/cards/shape_card/shape_card_state.dart';

class ShapeCustomPainter extends CustomPainter {
  final ShapeCardState shapeCardState;

  ShapeCustomPainter({
    required this.shapeCardState,
  });

  @override
  void paint(Canvas canvas, Size size) {
    // +0.5 because of small space between two custom painters
    const double left = 0;
    final double top = shapeCardState == ShapeCardState.onlyPlusButtonShape ? 0.5 : 0;
    final double right = size.width;
    final double bottom = size.height+0.5;
    final shapeBounds = Rect.fromLTRB(left, top, right, bottom);

    final paint = Paint()
      ..color = myTheme().cardColor
      ..style = PaintingStyle.fill;

    // plus button shape
    if (shapeCardState == ShapeCardState.onlyPlusButtonShape) {
      _paintPlusButtonShape(shapeBounds, canvas, paint);
    } else {
      if(shapeCardState == ShapeCardState.attachShape){
        _paintPlusButtonShape(shapeBounds, canvas, paint);
      }

      // cutout shape for header and body of card
      _paintCutoutShape(shapeBounds, canvas, paint);
    }
  }

  void _paintCutoutShape(Rect shapeBounds, Canvas canvas, Paint paint) {
    const int padding = 10; // it makes space between plus button shape and cutout shape
    const int borderRadius = 12; // radius for corners
    final bottomPath = Path(); // path to paint cutout shape

    // left bottom corner
    bottomPath.moveTo(shapeBounds.bottomLeft.dx+borderRadius, shapeBounds.bottomLeft.dy);
    bottomPath.conicTo(shapeBounds.left, shapeBounds.bottom, shapeBounds.left, shapeBounds.bottom-borderRadius, 1);

    // left top corner
    bottomPath.lineTo(shapeBounds.left, shapeBounds.top+padding+borderRadius);
    bottomPath.conicTo(shapeBounds.left, shapeBounds.top+padding, shapeBounds.left + borderRadius, shapeBounds.top+padding, 1);

    // top shape
    if(shapeCardState == ShapeCardState.attachShape){
      bottomPath.lineTo(shapeBounds.width / 2 - 95, shapeBounds.top+padding);
      bottomPath.conicTo(shapeBounds.width / 2 - 50, shapeBounds.top+padding, shapeBounds.width / 2 -25, shapeBounds.top+padding+15, 1);

      bottomPath.quadraticBezierTo(shapeBounds.width / 2, shapeBounds.top + 30 + padding, shapeBounds.width / 2 +25, shapeBounds.top+15+padding);

      bottomPath.conicTo(shapeBounds.width / 2 + 50, shapeBounds.top+padding, shapeBounds.width / 2 +95, shapeBounds.top+padding, 1);
      bottomPath.lineTo(shapeBounds.topRight.dx-borderRadius, shapeBounds.top+padding);
    } else {
      bottomPath.lineTo(shapeBounds.right -borderRadius, shapeBounds.top+padding);
    }

    // right top corner
    bottomPath.conicTo(shapeBounds.topRight.dx, shapeBounds.top+padding,shapeBounds.topRight.dx, shapeBounds.top+borderRadius+padding,  1);

    // right bottom corner
    bottomPath.lineTo(shapeBounds.width, shapeBounds.bottom-borderRadius);
    bottomPath.conicTo(shapeBounds.right, shapeBounds.bottom,shapeBounds.width-borderRadius, shapeBounds.bottom,  1);

    // paint the path
    bottomPath.close();
    canvas.drawPath(bottomPath, paint);
  }

  void _paintPlusButtonShape(Rect shapeBounds, Canvas canvas, Paint paint) {
    final topPath = Path(); // path to paint top shape for plus button

    topPath.moveTo(shapeBounds.width / 2 - 95, shapeBounds.top);
    topPath.conicTo(shapeBounds.width / 2 - 50, shapeBounds.top, shapeBounds.width / 2 -25, shapeBounds.top+15, 1);

    topPath.quadraticBezierTo(shapeBounds.width / 2, shapeBounds.top + 30, shapeBounds.width / 2 +25, shapeBounds.top+15);

    topPath.conicTo(shapeBounds.width / 2 + 50, shapeBounds.top, shapeBounds.width / 2 +95, shapeBounds.top, 1);

    topPath.close();
    canvas.drawPath(topPath, paint);
  }

  @override
  bool shouldRepaint(ShapeCustomPainter oldDelegate) {
    return false;
  }
}
