import 'package:flutter/material.dart';
import 'package:training_lights/models/training_model/blick.dart';
import 'package:training_lights/routes/create_training_route/numerical_values.dart';
import 'package:training_lights/routes/create_training_route/widgets/buttons/color_selection_button.dart';
import 'package:training_lights/routes/create_training_route/widgets/counter_row.dart';
import 'package:training_lights/routes/create_training_route/widgets/lights_multichoice_list.dart';
import 'package:training_lights/utils/languages/language.dart';

class BlickContent extends StatelessWidget {
  final int numberOfLights;
  final BlickModel blick;
  final Function() wasSomethingEdited;

  const BlickContent({
    required this.numberOfLights,
    required this.blick,
    required this.wasSomethingEdited,
  });

  @override
  Widget build(BuildContext context) {
    final language = Language.of(context);

    return Column(
      children: [
        LightsMultiChoiceList(
          numberOfLights: numberOfLights,
          selectedLights: blick.selectedLights,
          wasSomethingEdited: wasSomethingEdited,
        ),
        CounterRow(
          label: language.createTrainingRouteTrainingBlickCardLengthOfBlick,
          value: blick.duration,
          incrementValue: NumericalValues.blickIncrementValue,
          maxValue: NumericalValues.blickMaxValue,
          editValue: (newValue) {
            blick.duration = newValue;
          },
          wasSomethingEdited: wasSomethingEdited,
        ),
        Padding(
            padding:
            const EdgeInsets.only(left: 16.0, right: 16.0, bottom: 20),
            child: ColorSelectionButton(
              blick: blick,
              wasSomethingEdited: wasSomethingEdited,
            ),
        )
      ],
    );
  }
}
