import 'package:flutter/material.dart';
import 'package:training_lights/common/buttons/action_circle_button.dart';
import 'package:training_lights/common/my_icons/my_icons.dart';
import 'package:training_lights/common/responsive/fitted_text.dart';
import 'package:training_lights/my_theme.dart';

class CounterRow extends StatefulWidget {
  final String label;
  final double value;
  final double incrementValue;
  final double maxValue;
  final bool inSeconds;
  final TextStyle? labelTextStyle;
  final Function(double) editValue;
  final Function() wasSomethingEdited;

  const CounterRow({
    required this.label,
    required this.value,
    required this.incrementValue,
    required this.maxValue,
    this.inSeconds = true,
    this.labelTextStyle,
    required this.editValue,
    required this.wasSomethingEdited,
  });

  @override
  State<StatefulWidget> createState() => _SettingsRow();
}

class _SettingsRow extends State<CounterRow> {
  late double _value;

  @override
  void initState() {
    _value = widget.value;
    super.initState();
  }

  void _callAllCallbacks() {
    widget.editValue(_value);
    widget.wasSomethingEdited();
  }

  void increment() {
    if (_value == widget.maxValue) {
      setState(() {
        _value = widget.incrementValue;
      });
    } else {
      setState(() {
        _value += widget.incrementValue;
      });
    }
    _callAllCallbacks();
  }

  void decrement() {
    if (_value == widget.incrementValue) {
      setState(() {
        _value = widget.maxValue;
      });
    } else {
      setState(() {
        _value -= widget.incrementValue;
      });
    }
    _callAllCallbacks();
  }

  @override
  Widget build(BuildContext context) {
    final theme = myTheme();

    return Padding(
      padding: const EdgeInsets.all(16),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          Flexible(
            child: Text(
                widget.label,
                style: widget.labelTextStyle ?? theme.textTheme.subtitle2,
            ),
          ),
          Row(
            children: [
              ActionCircleButton(
                onPressed: decrement,
                icon: MyIcons.minus,
              ),
              SizedBox(
                width: widget.inSeconds ? 45 : 35,
                child: Center(
                    child: FittedText(
                        '${_isValueRoundNumber() ? _value.toInt() : _value}'
                            '${widget.inSeconds ? 's' : ''}',
                        style: theme.textTheme.subtitle2,
                    ),
                ),
              ),
              ActionCircleButton(
                onPressed: increment,
                icon: MyIcons.plus,
              ),
            ],
          )
        ],
      ),
    );
  }

  bool _isValueRoundNumber() {
    return _value == _value.round();
  }
}
