import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:training_lights/common/buttons/primary_button.dart';
import 'package:training_lights/common/wrappers/my_dialog.dart';
import 'package:training_lights/global/enums/primary_button_design.dart';
import 'package:training_lights/models/training_model/blick.dart';
import 'package:training_lights/models/training_model/blick_pause.dart';
import 'package:training_lights/models/training_model/blick_prep.dart';
import 'package:training_lights/models/training_model/blick_random.dart';
import 'package:training_lights/models/training_model/training_element.dart';
import 'package:training_lights/utils/languages/language.dart';

class PlusButtonsDialog extends StatelessWidget {
  final int index;
  final Function(int, TrainingElement) addTrainingElement;

  const PlusButtonsDialog({
    required this.index,
    required this.addTrainingElement,
  });

  @override
  Widget build(BuildContext context) {
    final language = Language.of(context);
    const spacer = SizedBox(
      width: 12,
      height: 12,
    );

    return MyDialog(
      content: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          Row(
            children: [
              _plusElementButton(
                context,
                language.createTrainingRoutePlusBlick,
                index,
                BlickModel.create(),
              ),
              spacer,
              _plusElementButton(
                context,
                language.createTrainingRoutePlusBlickRandom,
                index,
                BlickRandomModel.create(),
              ),
            ],
          ),
          spacer,
          Row(
            children: [
              _plusElementButton(
                context,
                language.createTrainingRoutePlusBlickPrep,
                index,
                BlickPrepModel.create(),
              ),
              spacer,
              _plusElementButton(
                context,
                language.createTrainingRoutePlusPause,
                index,
                BlickPauseModel.create(),
              )
            ],
          ),
        ],
      ),
    );
  }

  Widget _plusElementButton(BuildContext context, String text, int index,
      TrainingElement trainingElement,) {
    return Expanded(
        child: PrimaryButton(
            buttonDesign: PrimaryButtonDesign.darkColorOnDark,
            onPressed: () {
              addTrainingElement(index, trainingElement);
              Navigator.of(context).pop();
            },
            text: '+ $text',
        ),
    );
  }
}
