import 'package:flutter/material.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/utils/languages/language.dart';

class LightsMultiChoiceList extends StatefulWidget {
  final Set<int> selectedLights;
  final int numberOfLights;
  final Function() wasSomethingEdited;

  const LightsMultiChoiceList({
    required this.selectedLights,
    required this.numberOfLights,
    required this.wasSomethingEdited,
  });

  @override
  _LightsMultiChoiceListState createState() => _LightsMultiChoiceListState();
}

class _LightsMultiChoiceListState extends State<LightsMultiChoiceList> {

  @override
  Widget build(BuildContext context) {
    final theme = myTheme();
    final language = Language.of(context);

    return ListView(
      shrinkWrap: true,
      physics: const NeverScrollableScrollPhysics(),
      children: [
        for (int i = 0 ; i < widget.numberOfLights; i++)
          CheckboxListTile(
            title: Text(
              '${language.stripe} ${i + 1}',
              style: theme.textTheme.subtitle2,
            ),
            controlAffinity: ListTileControlAffinity.trailing,
            value: widget.selectedLights.contains(i),
            onChanged: (value){
              // At least one light has to be selected
              if (!value! && widget.selectedLights.length == 1) {
                return;
              }

              setState(() {
                value ? widget.selectedLights.add(i) : widget.selectedLights.remove(i);

              });
              widget.wasSomethingEdited();
            },
          )
      ],
    );
  }
}
