import 'package:flutter/material.dart';
import 'package:training_lights/common/my_icons/my_icons.dart';
import 'package:training_lights/models/training_model/training_element.dart';
import 'package:training_lights/routes/create_training_route/widgets/cards/training_element_card.dart';
import 'package:training_lights/routes/create_training_route/widgets/dialogs/plus_buttons_dialog.dart';
import 'package:training_lights/utils/show_dialog.dart';

class TrainingElementsList extends StatefulWidget {
  final List<TrainingElement> trainingElements;
  final int numberOfLights;
  final Function() wasSomethingEdited;
  final Widget spacer;

  const TrainingElementsList({
    required this.trainingElements,
    required this.numberOfLights,
    required this.wasSomethingEdited,
    required this.spacer,
  });

  @override
  TrainingElementsListState createState() => TrainingElementsListState();
}

class TrainingElementsListState extends State<TrainingElementsList> {
  late GlobalKey<AnimatedListState> _animationGlobalKey;

  @override
  void initState() {
    super.initState();
    _animationGlobalKey = GlobalKey<AnimatedListState>();
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        IconButton(
            onPressed: () => _showPlusElementButtons(0),
            icon: const Icon(MyIcons.plus),
        ),
        AnimatedList(
          key: _animationGlobalKey,
          padding: EdgeInsets.zero,
          shrinkWrap: true,
          physics: const NeverScrollableScrollPhysics(),
          initialItemCount: widget.trainingElements.length,
          itemBuilder: (context, index, animation) {
            return _buildTrainingElement(widget.trainingElements[index], index, animation);
          },
        ),
      ],
    );
  }

  Widget _buildTrainingElement(TrainingElement trainingElement, int index,
      Animation<double> animation,) {
    return SizeTransition(
        sizeFactor: animation,
        child: TrainingElementCard(
          numberOfLights: widget.numberOfLights,
          index: index,
          trainingElement: trainingElement,
          trainingElements: widget.trainingElements,
          onDelete: _removeTrainingElement,
          wasSomethingEdited: widget.wasSomethingEdited,
          showPlusElementButtons: _showPlusElementButtons,
          scrollToAddedWidget: (BuildContext context) =>
              _scrollToAddedWidget(context, animation),
        ),
    );
  }

  void _showPlusElementButtons(int index) {
    ShowDialog.show(
      context: context,
      child: PlusButtonsDialog(
        index: index,
        addTrainingElement: _addTrainingElement,
      ),
    );
  }

  void _scrollToAddedWidget(BuildContext context, Animation<double> animation) {
    if (animation.status == AnimationStatus.forward) {
      animation.addStatusListener((status) {
        if (status == AnimationStatus.completed) {
          Scrollable.ensureVisible(context,
              duration: const Duration(milliseconds: 1000),
          );
        }
      });
    }
  }

  void _addTrainingElement(int index, TrainingElement trainingElement) {
    _animationGlobalKey.currentState!
        .insertItem(index, duration: const Duration(milliseconds: 500));
    widget.trainingElements.insert(index, trainingElement);
    widget.wasSomethingEdited();
  }

  void _removeTrainingElement(int index) {
    final TrainingElement removedTrainingElement =
        widget.trainingElements.removeAt(index);

    _animationGlobalKey.currentState!.removeItem(
        index,
        (_, animation) => _buildTrainingElement(
            removedTrainingElement, index, animation,),
        duration: const Duration(milliseconds: 500),
    );

    widget.wasSomethingEdited();
  }
}
