import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:training_lights/common/buttons/connection_state_button.dart';
import 'package:training_lights/common/buttons/menu_button.dart';
import 'package:training_lights/common/buttons/primary_button.dart';
import 'package:training_lights/common/wrappers/my_scaffold.dart';
import 'package:training_lights/global/enums/primary_button_design.dart';
import 'package:training_lights/global/services.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/utils/languages/language.dart';

class HomeRoute extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    final language = Language.of(context);
    final navigator = Navigator.of(context);
    const spacer8 = SizedBox(height: 8);
    const padding = EdgeInsets.symmetric(horizontal: 20);

    return MyScaffold(
      title: const ConnectionStateButton(),
      actionButton: MenuButton(),
      isBackButtonDisplayed: false,
      isBottomGradientDisplayed: false,
      zeroBodyPadding: true,
      body: Column(
        children: [
          Expanded(
            child: Center(
              child: _image(),
            ),
          ),
          Padding(
            padding: padding,
            child: Column(
              mainAxisAlignment: MainAxisAlignment.end,
              children: [
                Align(
                  alignment: Alignment.centerLeft,
                  child: Text(
                    language.homeRouteWelcomeTitle,
                    style: myTheme().textTheme.headline1,
                  ),
                ),
                spacer8,
                Align(
                  alignment: Alignment.centerLeft,
                  child: Text(
                    language.homeRouteSubtitle,
                    style: myTheme().textTheme.subtitle2,
                  ),
                ),
                const SizedBox(height: 20),
                PrimaryButton(
                  onPressed: () {
                    navigator.pushNamed('/control');
                  },
                  text: language.homeRouteManual,
                ),
                spacer8,
                PrimaryButton(
                  buttonDesign: PrimaryButtonDesign.accentColorOnDark,
                  onPressed: () {
                    navigator.pushNamed('/trainings');
                  },
                  text: language.homeRouteTrainings,
                ),
                const SizedBox(height: 50)
              ],
            ),
          ),
        ],
      ),
    );
  }

  Widget _image() {
    return Consumer<Services>(
      builder: (_, services, __) {
        final openAppCount = services.sharedPrefs.getOpenAppNumber();
        final imageIndex = openAppCount % 4;
        return Image(
          image: AssetImage('assets/images/main_screen_$imageIndex.jpg'),
        );
      },
    );
  }
}
