import 'package:flutter/material.dart';
import 'package:training_lights/common/buttons/connection_state_button.dart';
import 'package:training_lights/common/my_icons/my_icons.dart';
import 'package:training_lights/common/responsive/fitted_text.dart';
import 'package:training_lights/common/wrappers/my_card.dart';
import 'package:training_lights/common/wrappers/my_scaffold.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/routes/about_us_route/about_us_route.dart';
import 'package:training_lights/routes/menu_route/widgets/back_menu_button.dart';
import 'package:training_lights/utils/languages/language.dart';
import 'package:training_lights/utils/launch_url.dart';

class MenuRoute extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    final language = Language.of(context);
    final theme = myTheme();
    const padding = EdgeInsets.symmetric(horizontal: 20);

    return MyScaffold(
        title: const ConnectionStateButton(),
        actionButton: BackMenuButton(),
        isBackButtonDisplayed: false,
        isBottomGradientDisplayed: true,
        body: Column(
          children: [
            Expanded(
              flex: 10,
              child: Center(
                  child: SingleChildScrollView(
                    child: Column(
                      mainAxisSize: MainAxisSize.min,
                      children: <Widget>[
                        _textButton(
                          context: context,
                          text: language.menuRouteHome,
                          routeName: '/',
                        ),
                        _spaceBetweenButtons(context),
                        _textButton(
                          context: context,
                          text: language.aboutUs,
                          routeName: '/aboutUs',
                          args: AboutUsRouteArgs(scrollDown: false),
                        ),
                        _spaceBetweenButtons(context),
                        _textButton(
                          context: context,
                          text: language.settings,
                          routeName: '/setting',
                        ),
                        _spaceBetweenButtons(context),
                        _textButton(
                          context: context,
                          text: language.contact,
                          routeName: '/contact',
                        ),
                      ],
                    ),
                  ),
              ),
            ),
            Expanded(
              flex: 2,
              child: Container(
                alignment: Alignment.center,
                padding: padding,
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: [
                    Expanded(
                      child: _socialNetworkButton(
                          context: context,
                          onTap: () => UrlLauncher.differentUrlsAppAndWeb(
                              'fb://page/104253511889581',
                              'https://www.facebook.com/traininglights2021',
                          ),
                          icon: MyIcons.facebook,
                      ),
                    ),
                    const SizedBox(width: 15,),
                    Expanded(
                      child: _socialNetworkButton(
                          context: context,
                          onTap: () => UrlLauncher.universalUrl(
                              'https://www.instagram.com/traininglights/',
                          ),
                          icon: MyIcons.instagram,
                      ),
                    ),
                    const SizedBox(width: 15,),
                    Expanded(
                      child: _socialNetworkButton(
                          context: context,
                          onTap: () => UrlLauncher.universalUrl(
                            'https://www.youtube.com/channel/UCRQfk74XtIAUxILYbrhEjnQ',
                          ),
                          icon: MyIcons.youtube,
                      ),
                    ),
                  ],
                ),
              ),
            ),
            Expanded(
              flex: 2,
              child: Container(
                padding: padding,
                child: Row(
                  children: [
                    Expanded(
                      child: Align(
                        alignment: Alignment.topLeft,
                        child: FittedText(
                          '${language.menuRouteVersion} 1.0.0', // TODO version from config
                          style: theme.textTheme.subtitle2,
                        ),
                      ),
                    ),
                    Expanded(
                      child: Align(
                        alignment: Alignment.topRight,
                        child: Image(
                          height: 19,
                          color: theme.textTheme.subtitle2!.color,
                          image: const AssetImage('assets/images/dsparx_logo.png'),
                        ),
                      ),
                    )
                  ],
                ),
              ),
            )
          ],
        ),
    );
  }

  Widget _socialNetworkButton({
    required BuildContext context,
    required Function() onTap,
    required IconData icon,
  }) {
    double height;
    final double screenHeight = MediaQuery.of(context).size.height;

    // because of padding by icon
    if (screenHeight * 0.06 > 80) {
      height = 80;
    } else if (screenHeight * 0.06 < 54) {
      height = 54;
    } else {
      height = screenHeight * 0.06;
    }

    return SizedBox(
      height: height,
      child: GestureDetector(
        onTap: onTap,
        child: MyCard(
          elevation: 0,
          margin: EdgeInsets.zero,
          child: Center(
              child: Icon(icon),
          ),
        ),
      ),
    );
  }

  Widget _textButton({
    required BuildContext context,
    required String text,
    required String routeName,
    Object? args,
  }) {
    return TextButton(
      onPressed: () => Navigator.of(context).pushNamed(
        routeName,
        arguments: args,
      ),
      child: Text(
        text,
        style: myTheme().textTheme.headline1,
        textAlign: TextAlign.center,
      ),
    );
  }

  Widget _spaceBetweenButtons(BuildContext context) {
    return SizedBox(height: MediaQuery.of(context).size.height * 0.02);
  }
}
