import 'package:flutter/material.dart';
import 'package:training_lights/common/buttons/primary_button.dart';
import 'package:training_lights/common/responsive/fitted_text.dart';
import 'package:training_lights/common/wrappers/my_card.dart';
import 'package:training_lights/common/wrappers/my_scaffold.dart';
import 'package:training_lights/models/training_model/training.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/routes/create_training_route/create_training_route.dart';
import 'package:training_lights/utils/languages/language.dart';

class NumberLightsRoute extends StatefulWidget {
  @override
  State<StatefulWidget> createState() => _NumberLightsRoute();
}

class _NumberLightsRoute extends State<NumberLightsRoute> {
  late int selectNumberOfLights;

  @override
  void initState() {
    selectNumberOfLights = 3;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    final language = Language.of(context);

    return OrientationBuilder(
      builder: (context, orientation) {
        return MyScaffold(
          title: Text(
            language.numberLightsRouteChooseNumberOfLights,
            style: myTheme().textTheme.headline2,
          ),
          isBackButtonDisplayed: true,
          isBottomGradientDisplayed: false,
          body: Column(
            children: [
              if (orientation == Orientation.portrait)
                Expanded(
                  child: Column(
                    children: _cardsChildren(language),
                  ),
                )
              else
                Expanded(
                  child: Row(
                    children: _cardsChildren(language),
                  ),
                ),
              Padding(
                padding: const EdgeInsets.only(top: 20, bottom: 40),
                child: PrimaryButton(
                  text: language.choose,
                  onPressed: () {
                    Navigator.of(context).pushReplacementNamed(
                        '/createTraining',
                        arguments: CreateTrainingRouteArgs(
                            initialTraining: TrainingModel.create(
                                language.trainingModelNewTraining,
                                selectNumberOfLights,
                            ),
                            editing: false,
                        ),
                    );
                  },
                ),
              )
            ],
          ),
        );
      },
    );
  }

  List<Widget> _cardsChildren(Language language) {
    return [
      _numberOfLightsButton(context, language, numberOfLights: 2),
      const SizedBox(height: 5,),
      _numberOfLightsButton(context, language, numberOfLights: 3),
      const SizedBox(height: 5,),
      _numberOfLightsButton(context, language, numberOfLights: 4),
    ];
  }

  Widget _numberOfLightsButton(BuildContext context, Language language,
      {required int numberOfLights,}) {
    return Expanded(
      child: MyCard(
        borderColor: selectNumberOfLights == numberOfLights ? myTheme().colorScheme.secondary : null,
        child: InkWell(
          highlightColor: myTheme().cardColor,
          onTap: () {
            setState(() {
              selectNumberOfLights = numberOfLights;
            });
          },
          child: Padding(
            padding: const EdgeInsets.all(2),
            child: Column(
              children: [
                Expanded(
                    flex: 16,
                    child: Row(
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: [
                        for (int i = 0 ; i < numberOfLights ; i++)
                          _circle(context),
                      ],
                    ),
                ),
                Divider(
                  height: 0,
                  thickness: 1,
                  color: myTheme().cardColor,
                ),
                Expanded(
                    flex: 5,
                    child: Center(
                      child: FittedText(
                        '$numberOfLights ${language.stripes}',
                        style: myTheme().textTheme.subtitle1,
                      ),
                    ),
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }

  Widget _circle(BuildContext context) {
    return Container(
      height: 40,
      width: 40,
      margin: const EdgeInsets.symmetric(
          horizontal: 5,
      ),
      decoration: BoxDecoration(
        color: myTheme().cardColor,
        shape: BoxShape.circle,
      ),
    );
  }
}
