import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:training_lights/common/buttons/primary_button.dart';
import 'package:training_lights/global/enums/primary_button_design.dart';
import 'package:training_lights/global/notify_listeners/battery_manager.dart';
import 'package:training_lights/global/notify_listeners/tangle_manager/tangle_manager.dart';
import 'package:training_lights/routes/pairing_route/widgets/connected/device_battery_card.dart';
import 'package:training_lights/routes/pairing_route/widgets/status_layout.dart';
import 'package:training_lights/utils/languages/language.dart';

class Ready extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    final language = Language.of(context);

    return Consumer<TangleManager>(
      builder: (_, tangle, __) {
        return StatusLayout(
          circularComplete: true,
          title: language.pairingRouteConnectedTitle,
          subtitle: language.pairingRouteConnectedSubtitle,
          icon: Consumer<BatteryManager>(
            builder: (_, battery, __) {
              return Column(
                children: battery.devices.map((battery) {
                  return BatteryDeviceCard(battery: battery);
                }).toList(),
              );
            },
          ),
          button: Column(
            children: [
              PrimaryButton(
                onPressed: () => Navigator.of(context).pop(),
                text: language.pairingRouteConnectedContinue,
              ),
              const SizedBox(height: 8,),
              PrimaryButton(
                onPressed: tangle.disconnect,
                text: language.pairingRouteConnectedDisconnect,
                buttonDesign: PrimaryButtonDesign.accentColorOnDark,
              ),
            ],
          ),
        );
      },
    );
  }
}
