import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:tangle_utils/tangle_utils.dart';
import 'package:training_lights/common/wrappers/my_card.dart';
import 'package:training_lights/my_theme.dart';

class BatteryDeviceCard extends StatelessWidget {
  final Battery battery;

  const BatteryDeviceCard({required this.battery});

  @override
  Widget build(BuildContext context) {
    return MyCard(
      child: Padding(
        padding: const EdgeInsets.all(8.0),
        child: Row(
          children: [
            Text('Stripe ${battery.deviceID} (${battery.deviceID + 1} LEDs)'),
            Expanded(child: Container()),
            Text('${battery.percentage}%'),
            Padding(
              padding: const EdgeInsets.only(right: 12, left: 8),
              child: BatteryIcon(percentage: battery.percentage,),
            ),
          ],
        ),
      ),
    );
  }

}

class BatteryIcon extends StatelessWidget {
  // lower bounds
  static const int full = 90;
  static const int threeQuarters = 65;
  static const int half = 40;
  static const int quarter = 10;

  final int percentage;

  const BatteryIcon({
    required this.percentage,
  });

  @override
  Widget build(BuildContext context) {
    return Icon(
      _icon(percentage),
      color: _color(percentage),
    );
  }

  IconData _icon(int percentage) {
    if (percentage >= full) {
      return FontAwesomeIcons.batteryFull;
    } else if (percentage >= threeQuarters) {
      return FontAwesomeIcons.batteryThreeQuarters;
    } else if (percentage >= half) {
      return FontAwesomeIcons.batteryHalf;
    } else if (percentage >= quarter) {
      return FontAwesomeIcons.batteryQuarter;
    } else {
      return FontAwesomeIcons.batteryEmpty;
    }
  }

  Color _color(int percentage) {
    if (percentage <= quarter) {
      return myTheme().errorColor;
    }
    return myTheme().colorScheme.secondary;
  }
}
