import 'dart:io';

import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:tangle_connector/tangle_connector.dart';
import 'package:training_lights/common/buttons/primary_button.dart';
import 'package:training_lights/common/wrappers/my_futurebuilder.dart';
import 'package:training_lights/common/wrappers/my_streambuilder.dart';
import 'package:training_lights/global/enums/primary_button_design.dart';
import 'package:training_lights/global/notify_listeners/scanner_state_manager.dart';
import 'package:training_lights/global/notify_listeners/tangle_manager/tangle_manager.dart';
import 'package:training_lights/global/services.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/routes/pairing_route/widgets/device_scanner/owned_device_card.dart';
import 'package:training_lights/routes/pairing_route/widgets/device_scanner/unadopted_device_card.dart';
import 'package:training_lights/routes/pairing_route/widgets/device_scanner/unupdated_device_card.dart';
import 'package:training_lights/utils/languages/language.dart';

class DeviceScanner extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    final language = Language.of(context);
    return Consumer<Services>(
        builder: (_, services, __) {
          return Consumer<TangleManager>(
            builder: (_, tangle, __) {
              return MyFutureBuilder(
                  future: services.gps.ensurePermissionGrantedAndServiceEnabled(isAndroid: Platform.isAndroid),
                  withConnectionState: true,
                  builder: (_) {
                    return MyStreamBuilder<TangleDevicesDTO>(
                      stream: services.bluetooth.scanTangleDevice(
                        ownerSignature: tangle.ownerSignature,
                        clearConnectedDevices: !context.read<ScannerStateManager>().actionInProgress,
                      ),
                      initialData: TangleDevicesDTO(
                          owned: [],
                          ownedToUpdate: [],
                          toAdopt: [],
                      ),
                      builder: (dto) {
                        return Column(
                          mainAxisAlignment: MainAxisAlignment.spaceAround,
                            children: [
                              Text(language.pairingRouteMyDevices, style: myTheme().textTheme.headline2),

                              ListView(
                                shrinkWrap: true,
                                physics: const NeverScrollableScrollPhysics(),
                                children: [
                                  ...dto.owned.map((device) => OwnedDeviceCard(device: device)).toList(),
                                  ...dto.ownedToUpdate.map((device) => UnupdatedDeviceCard(device: device)).toList(),
                                ],
                              ),
                              const Spacer(),
                              Text(language.pairingRouteDevicesToAdopt, style: myTheme().textTheme.headline2),
                              const SizedBox(height: 20,),
                              ListView(
                                shrinkWrap: true,
                                physics: const NeverScrollableScrollPhysics(),
                                children: [
                                  ...dto.toAdopt.map((device) => UnadoptedDeviceCard(
                                      device: device,
                                  ),).toList(),
                                ],
                              ),
                              const Spacer(),
                              Consumer<ScannerStateManager>(
                                builder: (_, stateManager, __) {
                                  return stateManager.buttonFromState(dto: dto);
                                },
                              ),
                              const SizedBox(height: 8),
                              PrimaryButton(
                                text: language.pairingRouteRefresh,
                                onPressed: () => services.bluetooth.startCleanScan(
                                  clearConnectedDevices: !context.read<ScannerStateManager>().actionInProgress,
                                ),
                                buttonDesign: PrimaryButtonDesign.accentColorOnDark,
                              ),
                              const SizedBox(height: 50),
                            ],
                        );
                      },
                    );
                  },
              );
            },
          );
        },
    );
  }
}
