import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:tangle_connector/tangle_connector.dart';
import 'package:training_lights/common/my_icons/my_icons.dart';
import 'package:training_lights/common/wrappers/my_card.dart';
import 'package:training_lights/global/notify_listeners/scanner_state_manager.dart';
import 'package:training_lights/global/notify_listeners/tangle_manager/tangle_manager.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/routes/pairing_route/widgets/device_scanner/device_info.dart';

class UnadoptedDeviceCard extends StatefulWidget {
  final TangleDevice device;

  const UnadoptedDeviceCard({
    required this.device,
  });

  @override
  State<StatefulWidget> createState() => _UnadoptedDeviceCardState();
}

class _UnadoptedDeviceCardState extends State<UnadoptedDeviceCard> {
  @override
  Widget build(BuildContext context) {
    final device = widget.device;
    return Consumer<ScannerStateManager>(
      builder: (_, stateManager, __) {
        final bool thisFailed = stateManager.deviceAdoptionFailed(device);
        final bool thisAdopting = stateManager.deviceAdoptionInProgress(device);
        return MyCard(
          borderColor: thisFailed ? myTheme().errorColor : null,
          child: Row(
            children: [
              DeviceInfo(device: device),
              Expanded(child: Container()),
              Consumer<TangleManager>(
                builder: (_, tangle, __) {
                  if (thisAdopting) {
                    return const Padding(
                      padding:  EdgeInsets.only(right: 8.0),
                      child:  CircularProgressIndicator(),
                    );
                  } else {
                    void Function()? onPressed = () => tangle.adopt(device: device);
                    Color? color = myTheme().colorScheme.secondary;
                    if (stateManager.adopting) {
                      onPressed = null;
                      color = null;
                    }

                    return IconButton(
                      onPressed: onPressed,
                      icon: Icon(
                          MyIcons.plus,
                          color: color,
                      ),
                    );
                  }
                },
              ),
            ],
          ),
        );
      },
    );
  }
}
