import 'package:flutter/material.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/utils/ratio_size.dart';

class StatusLayout extends StatelessWidget {
  final Widget icon;
  final String title;
  final String subtitle;
  final Widget? button;
  final bool circularComplete;

  const StatusLayout({
    required this.icon,
    required this.title,
    required this.subtitle,
    this.button,
    this.circularComplete = false,
  });

  @override
  Widget build(BuildContext context) {
    final ratioSize = RatioSize.getRatioSizeOfSmallerSide(context, 0.5);
    final mediaQueryHeight = MediaQuery.of(context).size.height;

    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Expanded(
            child: Stack(
              children: [
                Center(
                  child: SizedBox(
                    height: ratioSize,
                    width: ratioSize,
                    child: CircularProgressIndicator(
                        color: myTheme().colorScheme.secondary,
                        strokeWidth: 15,
                        value: circularComplete ? 1 : null,
                    ),
                  ),
                ),
                Center(child: icon),
              ],
            ),
        ),
        Expanded(
            child: Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Flexible(
                  child: ListView(
                    shrinkWrap: true,
                    children: [
                      Text(
                          title,
                          style: myTheme().textTheme.headline1,
                      ),
                      SizedBox(height: mediaQueryHeight * 0.01,),
                      Text(
                          subtitle,
                          style: myTheme().textTheme.subtitle2,
                      ),
                    ],
                  ),
                ),
                SizedBox(height: mediaQueryHeight * 0.02,),
                if ( button != null)
                  button!
              ],
            ),
        )
      ],
    );
  }
}
