import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:training_lights/common/buttons/menu_button.dart';
import 'package:training_lights/common/buttons/primary_button.dart';
import 'package:training_lights/common/dialogs/delete_dialog.dart';
import 'package:training_lights/common/scaffold_titles/left_align_text_title.dart';
import 'package:training_lights/common/wrappers/my_scaffold.dart';
import 'package:training_lights/global/enums/primary_button_design.dart';
import 'package:training_lights/global/notify_listeners/tangle_manager/tangle_manager.dart';
import 'package:training_lights/global/notify_listeners/training_manager.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/routes/setting_route/widgets/cards/notifications_switch.dart';
import 'package:training_lights/routes/setting_route/widgets/dropdown/language_dropdown.dart';
import 'package:training_lights/utils/languages/language.dart';
import 'package:training_lights/utils/show_dialog.dart';

class SettingRoute extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    final language = Language.of(context);
    const spacer8 = SizedBox(height: 8);
    const spacer24 = SizedBox(height: 24);

    return MyScaffold(
        title: LeftAlignTextTitle(
          text: language.settings,
        ),
        alignTitleLeft: true,
        actionButton: MenuButton(),
        isBackButtonDisplayed: false,
        isBottomGradientDisplayed: false,
        body: ListView(
            children: [
              _buildTitle(language.settingsRouteLanguagePick),
              spacer8,
              LanguageDropdown(),
              spacer24,
              _buildTitle(language.settingRouteNotifications),
              spacer8,
              NotificationsSwitch(),
              spacer24,
              _buildTitle(language.settingRouteOtherActions),
              spacer8,
              _buildActions(context, language),
              spacer8,
            ],
        ),
    );
  }

  Widget _buildTitle(String text) {
    return Align(
      alignment: Alignment.centerLeft,
      child: Text(text, style: myTheme().textTheme.subtitle2),
    );
  }

  Widget _buildActions(BuildContext context, Language language) {
    return Consumer<TangleManager>(
      builder: (_, tangle, __) {
        return Column(
          children: [
            PrimaryButton(
              text: tangle.isReady
                  ? language.settingRouteDisconnectLights
                  : language.settingRouteConnectLights,
              onPressed: () =>
              tangle.isReady
                  ? tangle.disconnect()
                  : Navigator.of(context).pushNamed('/pairing'),
              buttonDesign:
              tangle.isReady
                  ? PrimaryButtonDesign.darkRedColor
                  : PrimaryButtonDesign.accentColorOnDark,
            ),
            const SizedBox(
              height: 16,
            ),
            PrimaryButton(
              text: language.settingRouteDeleteAllTrainings,
              onPressed: () => _deleteAllTrainings(language, context),
              buttonDesign: PrimaryButtonDesign.darkRedColor,
            )
          ],
        );
      },
    );
  }

  Future<void> _deleteAllTrainings(Language language, BuildContext context) async {
    final trainingManager = context.read<TrainingManager>();
    final popRoute = Navigator.of(context).pop;
    final language = Language.of(context);
    final deleteTrainings = language.settingRouteDeleteAllTrainings;

    ShowDialog.show(
      context: context,
      child: DeleteDialog(
        onYes: () async {
          await trainingManager.deleteAll();
          popRoute();
        },
        title: deleteTrainings,
        contentText: language.areYouSureWantDoIrreversibleAction(deleteTrainings),
      ),
    );
  }
}
