import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:training_lights/common/wrappers/my_card.dart';
import 'package:training_lights/global/notify_listeners/notifications_manager.dart';
import 'package:training_lights/global/services.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/utils/languages/language.dart';

class NotificationsSwitch extends StatefulWidget {
  @override
  _NotificationsSwitchState createState() => _NotificationsSwitchState();
}

class _NotificationsSwitchState extends State<NotificationsSwitch> {
  late bool _isEnabled;

  @override
  void initState() {
    super.initState();
    _isEnabled = context.read<NotificationsManager>().notificationsEnabled;
  }

  void _setNotificationSetting() {
    context.read<NotificationsManager>().setNotifications(
        enabled: _isEnabled,
    );
  }

  void _storeNotificationSetting() {
    context.read<Services>().sharedPrefs.storeNotificationsSettings(
        notificationsEnabled: _isEnabled,
    );
  }

  @override
  Widget build(BuildContext context) {
    return MyCard(
      child: Padding(
        padding: const EdgeInsets.only(top: 4.0, bottom: 4.0),
        child: SwitchListTile.adaptive(
          title: Text(
            Language.of(context).settingRouteSendingNotifications,
            style: myTheme().textTheme.subtitle1,
          ),
          value: _isEnabled,
          onChanged: (_) {
            setState(() {
              _isEnabled = !_isEnabled;
              _setNotificationSetting();
              _storeNotificationSetting();
            });
          },
          tileColor: Colors.transparent,
          activeColor: myTheme().colorScheme.secondary,
        ),
      ),
    );
  }
}
