import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:training_lights/common/wrappers/my_card.dart';
import 'package:training_lights/global/notify_listeners/language_manager/language_manager.dart';
import 'package:training_lights/global/services.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/utils/languages/language.dart';

class LanguageDropdown extends StatelessWidget {
  void _setSelectedLanguage(LanguageManager languageNotifier, Language language) {
    languageNotifier.setLocale(language);
  }

  @override
  Widget build(BuildContext context) {
    final language = Language.of(context);
    final textStyle = myTheme().textTheme.subtitle1;

    return Consumer<LanguageManager>(
      builder: (_, languageNotifier, __) {
        return MyCard(
          child: ExpansionTile(
            key: UniqueKey(),
            title: Text(language.languageName, style: textStyle,),
            backgroundColor: Colors.transparent,
            children: _buildDropdownItems(languageNotifier, language, textStyle),
          ),
        );
      },
    );
  }

  List<Widget> _buildDropdownItems(LanguageManager languageNotifier,
      Language selectedLanguage, TextStyle? textStyle,) {
    return Language.allSupportedLanguages().map<Widget>((language) {
      if(language.languageName != selectedLanguage.languageName){
        return Consumer<Services>(
          builder: (_, services, __) {
            return ListTile(
              title: Text(language.languageName, style: textStyle,),
              onTap: () {
                _setSelectedLanguage(languageNotifier, language);
                services.sharedPrefs.storeSelectedLanguage(language);
              },
            );
          },
        );
      }  else {
        return Container(height: 0,);
      }
    }).toList();
  }
}
