import 'dart:math' as math;
import 'package:flutter/material.dart';
import 'package:training_lights/common/my_icons/my_icons.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/routes/tangle_control_route/tangle_control_card_state.dart';

class TangleLightPickerButton extends StatelessWidget {
  final TangleControlCardState cardState;
  final void Function(TangleControlCardState state) setCardState;

  const TangleLightPickerButton({
    required this.cardState,
    required this.setCardState,
  });

  @override
  Widget build(BuildContext context) {
    final theme = myTheme();

    return Container(
      height: 40,
      decoration: BoxDecoration(
        color: cardState == TangleControlCardState.lightSelection ?
        theme.highlightColor : theme.backgroundColor,
        shape: BoxShape.circle,
      ),
      child: TweenAnimationBuilder(
        tween: Tween<double>(
          begin: 0,
          end: cardState == TangleControlCardState.lightSelection ? math.pi : 0,
        ),
        duration: const Duration(milliseconds: 300),
        builder: (context, angle, child) {
          return Transform.rotate(angle: angle! as double, child: child,);
        },
        child: IconButton(
            splashRadius: 20,
            color: cardState == TangleControlCardState.lightSelection ?
            theme.primaryColor : null,
            onPressed: cardState == TangleControlCardState.colorSelection ?
            null : () {
              switch (cardState) {
                case TangleControlCardState.onlyControlButton:
                  setCardState(TangleControlCardState.lightSelection);
                  break;
                case TangleControlCardState.lightSelection:
                  setCardState(TangleControlCardState.onlyControlButton);
                  break;
                default:
                  break;
              }
            },
            icon: const Icon(MyIcons.dropdown),
        ),
      ),
    );
  }

}
