import 'package:flutter/material.dart';
import 'package:training_lights/global/enums/tangle_color.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/routes/tangle_control_route/tangle_control_card_state.dart';
import 'package:training_lights/routes/tangle_control_route/widgets/tangle_control_card/tangle_control_card_body.dart';
import 'package:training_lights/routes/tangle_control_route/widgets/tangle_control_card/tangle_control_card_title.dart';

class TangleControlCard extends StatefulWidget {
  final int defaultLightNumber;
  final int numberOfLights;

  const TangleControlCard({
    required this.defaultLightNumber,
    required this.numberOfLights,
  });

  @override
  _TangleControlCard createState() => _TangleControlCard();
}

class _TangleControlCard extends State<TangleControlCard> {
  late TangleControlCardState _cardState;
  late int _defaultLightNumber;
  late TangleColor _color;

  @override
  void initState() {
    super.initState();
    _cardState = TangleControlCardState.onlyControlButton;
    _defaultLightNumber = widget.defaultLightNumber;
    switch (_defaultLightNumber) {
      case 1:
        _color = TangleColor.red;
        break;
      case 2:
        _color = TangleColor.green;
        break;
      case 3:
        _color = TangleColor.blue;
        break;
      case 4:
        _color = TangleColor.white;
        break;
    }
  }

  void setCardState(TangleControlCardState newCardState) {
    setState(() => _cardState = newCardState);
  }

  void setLightNumber(int? newLightNumber) {
    setState(() => _defaultLightNumber = newLightNumber ?? _defaultLightNumber);
  }

  void setColor(TangleColor newColor) {
    setState(() => _color = newColor);
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: const EdgeInsets.only(bottom: 10),
      padding: const EdgeInsets.only(bottom: 5, left: 5, right: 5),
      decoration: BoxDecoration(
        color: myTheme().backgroundColor,
        borderRadius: BorderRadius.circular(15),
      ),
      child: Column(
        children: [
          TangleControlCardTitle(
            setCardState: setCardState,
            cardState: _cardState,
            lightNumber: _defaultLightNumber,
            numberOfLights: widget.numberOfLights,
          ),
          Expanded(
            child: TangleControlCardBody(
              lightNumber: _defaultLightNumber,
              numberOfLights: widget.numberOfLights,
              cardState: _cardState,
              color: _color,
              setColor: setColor,
              setLightNumber: setLightNumber,
            ),
          ),
        ],
      ),
    );
  }
}
