import 'package:flutter/material.dart';
import 'package:training_lights/common/responsive/fitted_text.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/routes/tangle_control_route/tangle_control_card_state.dart';
import 'package:training_lights/routes/tangle_control_route/widgets/buttons/tangle_color_picker_button.dart';
import 'package:training_lights/routes/tangle_control_route/widgets/buttons/tangle_light_picker_button.dart';
import 'package:training_lights/utils/languages/language.dart';

class TangleControlCardTitle extends StatelessWidget {
  final TangleControlCardState cardState;
  final int lightNumber;
  final int numberOfLights;
  final void Function(TangleControlCardState newState) setCardState;

  const TangleControlCardTitle({
    required this.cardState,
    required this.lightNumber,
    required this.numberOfLights,
    required this.setCardState,
  });

  @override
  Widget build(BuildContext context) {
    final theme = myTheme();
    return Padding(
      padding: const EdgeInsets.only(top: 8, bottom: 8, left: 12),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          Flexible(
            child: FittedText(
              _title(context),
              style: theme.textTheme.subtitle1,
            ),
          ),
          Row(
            children: [
              const SizedBox(width: 5),
              TangleColorPickerButton(
                cardState: cardState,
                setCardState: setCardState,
              ),
              TangleLightPickerButton(
                cardState: cardState,
                setCardState: setCardState,
              ),
            ],
          )
        ],
      ),
    );
  }

  String _title(BuildContext context) {
    final width = MediaQuery.of(context).size.width;

    if (numberOfLights >= 4 && width < 700) {
      return '$lightNumber';
    } else {
      return '${Language.of(context).stripe} $lightNumber';
    }
  }

}
