import 'package:flutter/material.dart';
import 'package:training_lights/common/buttons/connection_state_button.dart';
import 'package:training_lights/common/buttons/menu_button.dart';
import 'package:training_lights/common/buttons/primary_button.dart';
import 'package:training_lights/common/wrappers/my_scaffold.dart';
import 'package:training_lights/global/enums/primary_button_design.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/routes/training_list_route/widgets/recommended_trainings.dart';
import 'package:training_lights/routes/training_list_route/widgets/user_trainings.dart';
import 'package:training_lights/utils/languages/language.dart';

class TrainingsListRoute extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    final language = Language.of(context);
    final theme = myTheme();
    const spacer = SizedBox(
      height: 20.0,
    );

    return MyScaffold(
      title: const ConnectionStateButton(),
      actionButton: MenuButton(),
      isBackButtonDisplayed: true,
      isBottomGradientDisplayed: false,
      sliverAppBar: true,
      body: ListView(
        children: [
          Align(
              alignment: Alignment.centerLeft,
              child: Text(
                  language.trainingListRouteMyTrainings,
                  style: theme.textTheme.headline1,
              ),
          ),
          spacer,
          UserTrainings(),
          spacer,
          PrimaryButton(
            buttonDesign: PrimaryButtonDesign.accentColorOnDark,
            onPressed: () {
              Navigator.of(context).pushNamed(
                '/numberLights',
              );
            },
            text: '+ ${language.trainingListRouteCreateTraining}',
          ),
          spacer,
          Align(
              alignment: Alignment.centerLeft,
              child: Text(
                  language.trainingListRouteRecommendedTrainings,
                  style: theme.textTheme.headline2,
              ),
          ),
          spacer,
          RecommendedTrainings(),
        ],
      ),
    );
  }
}
