import 'package:flutter/material.dart';
import 'package:training_lights/common/buttons/play_training_button.dart';
import 'package:training_lights/common/buttons/primary_button.dart';
import 'package:training_lights/common/cards/thumbnail_card.dart';
import 'package:training_lights/global/enums/primary_button_design.dart';
import 'package:training_lights/models/training_model/recommended_training_model/recommended_training.dart';
import 'package:training_lights/utils/languages/language.dart';

class RecommendedTrainingCard extends StatelessWidget {
  final RecommendedTraining recommendedTraining;

  const RecommendedTrainingCard({
    required this.recommendedTraining,
  });

  @override
  Widget build(BuildContext context) {
    final language = Language.of(context);
    void onTap() => Navigator.of(context).pushNamed(
      '/recommendedTraining',
      arguments: recommendedTraining,
    );

    return ThumbnailCard(
        thumbnailKey: recommendedTraining.key,
        title: recommendedTraining.name,
        subtitle: '${recommendedTraining.trainingModel.numberOfLights} ${language.stripes}',
        description: recommendedTraining.description,
        onTap: onTap,
        actionButtons: Row(
          mainAxisAlignment: MainAxisAlignment.spaceAround,
          children: <Widget>[
            Expanded(
              child: PlayTrainingButton(training: recommendedTraining.trainingModel),
            ),
            const SizedBox(width: 8),
            Expanded(
                child: PrimaryButton(
                  buttonDesign: PrimaryButtonDesign.accentColorOnDark,
                  onPressed: onTap,
                  text: language.display,
                ),
            )
          ],
        ),
    );
  }
}
