import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:training_lights/common/buttons/play_training_button.dart';
import 'package:training_lights/common/buttons/primary_button.dart';
import 'package:training_lights/common/dialogs/delete_training_dialog.dart';
import 'package:training_lights/common/wrappers/my_card.dart';
import 'package:training_lights/global/enums/primary_button_design.dart';
import 'package:training_lights/global/notify_listeners/training_manager.dart';
import 'package:training_lights/models/training_model/training.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/routes/create_training_route/create_training_route.dart';
import 'package:training_lights/utils/languages/language.dart';
import 'package:training_lights/utils/show_dialog.dart';

class UserTrainingCard extends StatelessWidget {
  final TrainingModel trainingModel;
  final bool dragging;

  const UserTrainingCard({
    required this.trainingModel,
    required this.dragging,
  });

  @override
  Widget build(BuildContext context) {
    final language = Language.of(context);
    const padding = 8.0;
    void onTap() => Navigator.of(context).pushNamed('/createTraining',
        arguments: CreateTrainingRouteArgs(
            initialTraining: trainingModel,
            editing: true,
        ),
    );

    return AnimatedContainer(
      duration: const Duration(milliseconds: 500),
      child: Opacity(
        opacity: dragging ? 0.7 : 1,
        child: MyCard(
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: <Widget>[
              ListTile(
                title: Text(
                    trainingModel.name,
                    style: myTheme().textTheme.headline2,
                ),
                subtitle: Text(
                  '${trainingModel.numberOfLights} ${language.stripes}',
                  style: myTheme().textTheme.subtitle2,
                ),
                trailing: _popupMenuButton(language),
              ),
              Padding(
                padding: const EdgeInsets.only(left: padding, right: padding, bottom: padding),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceAround,
                  children: <Widget>[
                    Expanded(
                      child: PlayTrainingButton(training: trainingModel),
                    ),
                    const SizedBox(width: 8),
                    Expanded(
                      child: PrimaryButton(
                        buttonDesign: PrimaryButtonDesign.accentColorOnDark,
                        onPressed: onTap,
                        text: language.edit,
                      ),
                    ),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }

  Widget _popupMenuButton(Language language) {
    return PopupMenuButton(
      color: myTheme().dialogBackgroundColor,
      shape: RoundedRectangleBorder(
          side: BorderSide(color: myTheme().highlightColor),
          borderRadius: BorderRadius.circular(12),
      ),
      elevation: 20,
      onSelected: (Function() function) => function(),
      itemBuilder: (context) {
        final trainingManager = context.read<TrainingManager>();
        return [
          _popupMenuItem(
              language.trainingListRouteCopy,
                  () => trainingManager.copy(trainingModel, context),
          ),
          _popupMenuItem(
              language.trainingListRouteDelete,
                  () => ShowDialog.show(
                  context: context,
                  child: DeleteTrainingDialog(
                      trainingModel: trainingModel,
                  ),
              ),
          ),
        ];
      },
    );
  }

  PopupMenuItem<Function()> _popupMenuItem(String text, Function() function) {
    return PopupMenuItem(
      value: function,
      child: Text(
        text,
        style: myTheme().textTheme.subtitle1,
      ),
    );
  }
}
