import 'package:flutter/material.dart';
import 'package:great_list_view/great_list_view.dart';
import 'package:provider/provider.dart';
import 'package:training_lights/common/wrappers/my_card.dart';
import 'package:training_lights/global/notify_listeners/training_manager.dart';
import 'package:training_lights/models/training_model/training.dart';
import 'package:training_lights/my_theme.dart';
import 'package:training_lights/routes/training_list_route/widgets/user_training_card.dart';
import 'package:training_lights/utils/languages/language.dart';

class UserTrainings extends StatefulWidget {
  @override
  _UserTrainingsState createState() => _UserTrainingsState();
}

class _UserTrainingsState extends State<UserTrainings> {
  late AnimatedListController animatedController;
  late TrainingManager trainingManager;

  @override
  void initState() {
    animatedController = AnimatedListController();
    trainingManager = context.read<TrainingManager>();
    super.initState();
  }

  @override
  void dispose() {
    trainingManager.setController(null);
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final language = Language.of(context);
    final theme = myTheme();

    return Consumer<TrainingManager>(
      builder: (_, __, ___) {
        final List<TrainingModel> trainings = trainingManager.trainings;

        if (trainings.isEmpty) {
          trainingManager.setController(null);
          return Align(
            alignment: Alignment.topCenter,
            child: Opacity(
              opacity: 0.6,
              child: Text(
                language.trainingListRouteEmptyTrainingListText,
                style: theme.textTheme.subtitle2,
              ),
            ),
          );
        }

        trainingManager.setController(animatedController);
        return AutomaticAnimatedListView<TrainingModel>(
          shrinkWrap: true,
          physics: const NeverScrollableScrollPhysics(),
          list: trainings,
          comparator: AnimatedListDiffListComparator<TrainingModel>(
              sameItem: (a, b) => a.tid == b.tid,
              sameContent: (a, b) => a.contentEqual(b),
          ),
          itemBuilder: (context, training, data) => data.measuring
              ? _emptyCard()
              : UserTrainingCard(
                trainingModel: training,
                dragging: data.dragging,
              ),
          //addAnimatedElevation: false,
          listController: animatedController,
          reorderModel: AnimatedListReorderModel(
            onReorderComplete: (index, dropIndex, slot) {
              trainingManager.move(indexFrom: index, indexTo: dropIndex);
              return true;
            },
            onReorderMove: (index, dropIndex) => true,
            onReorderStart: (index, dx, dy) => true,
          ),

        );
      },
    );
  }

  Widget _emptyCard() {
    return const MyCard(
      child: SizedBox(
        height: 132, // height of basic m
      ),
    );
  }
}
